@@ -16,8 +16,8 @@
 
 #include <memory>
 
-#include "eckit/io/DataHandle.h"
 #include "eckit/exception/Exceptions.h"
+#include "eckit/io/DataHandle.h"
 
 #include "metkit/mars/BaseProtocol.h"
 #include "metkit/mars/MarsRequest.h"
@@ -30,29 +30,28 @@ public:
 
     class RetryTransfer : public eckit::Exception {
         virtual bool retryOnClient() const { return true; }
+
     public:
-        RetryTransfer(const std::string& what):
-            eckit::Exception(what) {}
+
+        RetryTransfer(const std::string& what) : eckit::Exception(what) {}
     };
 
 public:
 
     MarsRequestHandle(eckit::Stream&);
 
-    MarsRequestHandle(const metkit::mars::MarsRequest& request,
-                      const eckit::Configuration& database);
+    MarsRequestHandle(const metkit::mars::MarsRequest& request, const eckit::Configuration& database);
 
-    MarsRequestHandle(const metkit::mars::MarsRequest& request,
-                      metkit::mars::BaseProtocol* protocol);
+    MarsRequestHandle(const metkit::mars::MarsRequest& request, metkit::mars::BaseProtocol* protocol);
 
     ~MarsRequestHandle();
 
     // -- Overridden methods (from Streamable)
     virtual std::string className() const override { return "MarsRequestHandle"; }
     virtual const eckit::ReanimatorBase& reanimator() const override;
-    static  const eckit::ClassSpec& classSpec();
+    static const eckit::ClassSpec& classSpec();
 
-private: // members
+private:  // members
 
     metkit::mars::MarsRequest request_;
 
@@ -60,7 +59,7 @@ private: // members
 
     bool opened_;
 
-private: // members
+private:  // members
 
     void print(std::ostream&) const override;
     void encode(eckit::Stream&) const override;
@@ -68,13 +67,13 @@ private: // members
     eckit::Length openForRead() override;
     void openForWrite(const eckit::Length&) override;
     void openForAppend(const eckit::Length&) override;
-    long read(void*, long ) override;
+    long read(void*, long) override;
     long write(const void*, long) override;
     void close() override;
     bool canSeek() const override;
 };
 
-}
-}
+}  // namespace mars
+}  // namespace metkit
 
 #endif
