@@ -32,9 +32,9 @@ public:  // methods
 
 private:  // methods
 
-    virtual void print(std::ostream& out) const override;
-    virtual void pass2(const MarsExpandContext& ctx, MarsRequest& request) override;
-    bool expand(const MarsExpandContext& ctx, std::string& value) const override;
+    void print(std::ostream& out) const override;
+    void pass2(const MarsExpandContext& ctx, MarsRequest& request) override;
+    bool expand(const MarsExpandContext& ctx, std::string& value, const MarsRequest& request) const override;
 };
 
 //----------------------------------------------------------------------------------------------------------------------
